import { useMutation } from "@apollo/client";
import { useRouter } from "@curi/react-universal";
import { Button, Paper } from "@mui/material";
import { Form, Formik } from "formik";
import { FC, useCallback } from "react";
import { YamlEditor } from "../commons/form/yaml-editor/yaml-editor";
import { Configuration } from "../generated/graphql";
import { SET_CONFIGURATION } from "./mutations";

type Values = Configuration;

interface Props {
  configuration: Configuration;
}
export const RuntimeConfigEditor: FC<Props> = ({ configuration }) => {
  const { history } = useRouter();
  const [setConfiguration] =
    useMutation<{ configuration: Configuration }>(SET_CONFIGURATION);
  const submitForm = useCallback(
    async (values: Values) => {
      await setConfiguration({ variables: { configuration: values } });
      history.go(-1);
    },
    [setConfiguration, history]
  );
  return (
    <Paper sx={{ p: 2 }}>
      <Formik<Values> initialValues={configuration ?? {}} onSubmit={submitForm}>
        {({ submitForm, isSubmitting, values }) => {
          return (
            <Form>
              <YamlEditor label="YAML" name="content" />
              <Button
                variant="contained"
                color="primary"
                type="submit"
                disabled={isSubmitting}
                onClick={submitForm}
                fullWidth
              >
                Submit
              </Button>
            </Form>
          );
        }}
      </Formik>
    </Paper>
  );
};
